@@ -1,7 +1,6 @@
 # -*- coding: utf-8 -*-
 """
 Unit tests for the flight_log_code.py.
-No tests are currently written for the GUI.
 
 @author Adrian Weishaeupl (aw6g15@soton.ac.uk)
 """
@@ -12,7 +11,6 @@ import json
 import sys
 from autoflpy.util import flight_log_code
 from datetime import datetime
-from shutil import copyfile
 from autoflpy.util import nearest_ICAO_finder
 from autoflpy.util.testing.check_str_in_content import *
 
@@ -184,15 +182,15 @@ class TestFlightLogCode(unittest.TestCase):
             self.flight_data_file_name)
         # Checks that the expected frame dimensions are the correct size.
         frame_dimensions = [17780, 95220, 22860, 25400, 57141, 44436, 57132,
-                            19044, 5, 3]
-        if len(frame_list) == 10:
+                            19044, 6, 4, 8]
+        if len(frame_list) == 11:
             for frame in range(len(frame_list)):
                 self.assertEqual(frame_list[frame].size,
                                  frame_dimensions[frame])
         else:
             # Raises a fault if the length of the frame_list is not as
             # expected.
-            raise ValueError('Frame list length is not as expected: {0} != 10'
+            raise ValueError('Frame list length is not as expected: {0} != 11'
                              .format(len(frame_list)))
 
     def test_checklist_finder(self):
@@ -295,7 +293,7 @@ class TestFlightLogCode(unittest.TestCase):
         data_frames = notebook_results[3]
         # Checks that the frames were split into the correct number of
         # subframes
-        self.assertEqual(len(data_frames), 10)
+        self.assertEqual(len(data_frames), 12)
         # Assigns expected titles
         data_frame_section_titles = [
             'Status_unavailable_GPS_20190123_Flight2',
@@ -306,7 +304,9 @@ class TestFlightLogCode(unittest.TestCase):
             'VibeX_mperspers_VIBE_20190123_Flight2',
             'NavRoll_unavailable_CTUN_20190123_Flight2',
             'AOA_degrees_AOA_20190123_Flight2',
-            'Action_time_hh:mm',
+            'Action_time_hh:mm_WEATHER_20190123_Flight2',
+            'take_off_direction_RUNWAY_20190123_Flight2',
+            'm_empty_kg_AIRCRAFT_20190123_Flight2',
             'Temp0_degC_ArduinoMicro_20190123_Flight2']
         correct_titles = 0
         # Runs through titles. Checks that each title can be called and adds 1
@@ -319,7 +319,7 @@ class TestFlightLogCode(unittest.TestCase):
             except KeyError:
                 self.assertEqual(1, 2)
         # Checks that all titles are correct
-        self.assertEqual(correct_titles, 10)
+        self.assertEqual(correct_titles, 12)
 
     def test_flight_data_and_axis(self):
         # Gets run in the Jupyter Notebook.
@@ -327,8 +327,8 @@ class TestFlightLogCode(unittest.TestCase):
         flight_data_and_axis = notebook_results[4]
         # Assigns expected titles
         expected_titles = ['GPS', 'RCIN', 'BARO', 'ARSP', 'ATT', 'VIBE',
-                           'CTUN', 'AOA', 'Action', 'ArduinoMicro']
-        # Checks that the titles are present and in the correct palace
+                           'CTUN', 'AOA', 'WEATHER', 'RUNWAY', 'AIRCRAFT', 'ArduinoMicro']
+        # Checks that the titles are present and in the correct place
         for item in range(len(expected_titles)):
             self.assertEqual(expected_titles[item], flight_data_and_axis[1][item][0])
 
@@ -365,6 +365,82 @@ class TestFlightLogCode(unittest.TestCase):
         for string in expected_results:
             self.assertTrue(string in read_data)
 
+    def test_multi_string_data_formatter(self):
+        """A method to test the multi_string_data_formatter()"""
+        # Assigns testing strings
+        input1 = "Fish,Ca t,Dog,35, Mouse,   89"
+        flight_names_1 = [1, 2, 3, 4, 5, 6]
+        debug_name_1 = "Input 1"
+        input2 = ""
+        flight_names_2 = [0, 1]
+        debug_name_2 = "Input 2"
+        input3 = "Fail1"
+        flight_names_3 = [7, 8]
+        debug_name_3 = "TEST"
+        # Assigns testing outputs
+        expected_output1 = ["Fish", "Cat", "Dog", "35", "Mouse", "89"]
+        expected_output2 = [""]
+        expected_output3 = False
+        # Tests that the method works as expected
+        self.assertEqual(flight_log_code.multi_string_data_formatter(input1, flight_names_1, debug_name_1),
+                         expected_output1)
+        self.assertEqual(flight_log_code.multi_string_data_formatter(input2, flight_names_2, debug_name_2),
+                         expected_output2)
+        try:
+            flight_log_code.multi_string_data_formatter(input3, flight_names_3, debug_name_3)
+            # Should raise an index error. If not, fail the test.
+            self.assertTrue(expected_output3)
+        except IndexError:
+            # Planned error
+            self.assertTrue(True)
+
+    def test_remove_dictionary_key(self):
+        """A method to test the remove_dictionary_key()"""
+        # Create variables
+        dictionary1 = {"DOG": "4F", "Mouse": "Cat", "Donkey": 7, 8906: "Fish", "PiG": "Farm"}
+        keys_to_remove = ["Mouse", 8906, "DOG"]
+        # Remove the keys and check if they have been removed
+        for key_index in range(len(keys_to_remove)):
+            output = flight_log_code.remove_dictionary_key(dictionary1, keys_to_remove[key_index])
+            if keys_to_remove[key_index] in output.keys():
+                # Fail if the key is still present
+                self.assertTrue(False)
+            else:
+                # Key successfully removed, pass the test
+                self.assertTrue(True)
+
+    def test_multi_dictionary_data_formatter(self):
+        """A method to test the multi_dictionary_data_formatter()"""
+        # Create variables
+        dictionary1 = {"DOG": "4F, Squirrel", "Mouse": "Cat, 78", "Donkey": "7, 7", 8906: "Fish , Bird",
+                       "PiG": "Farm, Animal"}
+        debug_name1 = "dict1"
+        flight_dates1 = [0, 1]
+        dictionary2 = {"Face": "Nose, Ear, Mouth"}
+        flight_dates2 = [2, 3]
+        debug_name2 = "TEST"
+
+        # Assigns expected outputs:
+        expected_output_dict1_1 = ["4F", "Cat", "7", "Fish", "Farm"]
+        expected_output_dict1_2 = ["Squirrel", "78", "7", "Bird", "Animal"]
+        key = ["DOG", "Mouse", "Donkey", 8906, "PiG"]
+        expected_output_dict2 = False
+
+        # Runs the method
+        output1 = flight_log_code.multi_dictionary_data_formatter(dictionary1, flight_dates1, debug_name1)
+
+        try:
+            flight_log_code.multi_dictionary_data_formatter(dictionary2, flight_dates2, debug_name2)
+            # Fails if this does not raise an error
+            self.assertTrue(expected_output_dict2)
+        except IndexError:
+            # Passes if an error is raised
+            self.assertFalse(expected_output_dict2)
+
+        for key_index in range(len(dictionary1.keys())):
+            self.assertEqual(output1[0][key[key_index]], expected_output_dict1_1[key_index])
+            self.assertEqual(output1[1][key[key_index]], expected_output_dict1_2[key_index])
+
 
 if __name__ == '__main__':
     unittest.main()
