@@ -1,8 +1,7 @@
 # -*- coding: utf-8 -*-
 """
-Unit tests for the flight_log_code.py and the log_to_xlsx.py
-codes. *** WORK IN PROGRESS ***
-No tests are currently written for the GUI.
+Unit tests for the log_to_xlsx.py
+code.
 
 @author Adrian Weishaeupl (aw6g15@soton.ac.uk)
 """
@@ -38,6 +37,7 @@ class TestLogToXlsx(unittest.TestCase):
         self.flight_number = self.data["log_to_xlsx_input"]["flight_number"]
         self.weather_data = self.data["weather_data"]
         self.runway_data = self.data["runway_data"]
+        self.aircraft_data = self.data["aircraft_data"]
 
     def test_log_reader(self):
         # Make sure the test workbook is closed.
@@ -49,7 +49,8 @@ class TestLogToXlsx(unittest.TestCase):
                                self.flight_date,
                                self.flight_number,
                                self.weather_data,
-                               self.runway_data)
+                               self.runway_data,
+                               self.aircraft_data)
 
         def worksheet_tester(sheet, cell, expected_answer):
             """
@@ -83,6 +84,30 @@ class TestLogToXlsx(unittest.TestCase):
             worksheet_tester(sheetlist[sheet], cell[sheet],
                              expected_answer[sheet])
 
+    def test_log_reader_multi(self):
+        # Defines relevant variables
+        log_file_paths = [self.log_file_path, self.log_file_path]
+        name_converter_file_path = self.name_converter_file_path
+        data_sources_path = self.data_sources_path
+        excel_file_path = self.excel_file_path
+        excel_file_names = ["test_xlsx", "test_xlsx_multi"]
+        flight_dates = [self.flight_date, "87654321"]
+        flight_numbers = [self.flight_number, "6"]
+        weather_data_multi = [self.weather_data, {'Action_time_hh:mm': 'DE:FG', 'Pressure_Pa': 'HIJ',
+                                                  'Temperature_C': 'KLMN', 'Wind_direction_degrees': 'OP',
+                                                  'Wind_speed_mps': 'ABC'}]
+        runway_data_multi = [self.runway_data, {'runway_surface': '1234', 'surface_condition': '45',
+                                                'take_off_direction': '678'}]
+        aircraft_data_multi = [self.aircraft_data, self.aircraft_data]
+
+        # Runs the multi-xlsx generator
+        log_to_xlsx.log_reader_multi(log_file_paths, name_converter_file_path, data_sources_path,
+                                     excel_file_path, excel_file_names, flight_dates, flight_numbers,
+                                     weather_data_multi, runway_data_multi, aircraft_data_multi)
+
+        # Checks that the second file has been made.
+        self.assertTrue(os.path.exists(self.base_path + "test_xlsx_multi.xlsx"))
+
 
 if __name__ == '__main__':
     unittest.main()
